/*


    ========== licence begin LGPL
    Copyright (C) 2002 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

package com.sap.dbtech.jdbc.translators;

import java.sql.*;
import com.sap.dbtech.util.*;
/**
 *
 */
class TimeTranslator extends CharDataTranslator {
    /**
     * TimeTranslator constructor comment.
     * @param mode int
     * @param ioType int
     * @param len int
     * @param ioLen int
     * @param bufpos int
     */
    protected TimeTranslator(int mode, int ioType, int dataType, int len, int ioLen, int bufpos) {
        super(mode, ioType, dataType, len, ioLen, bufpos);
    }
    /**
     *
     * @return java.sql.Date
     */
    public Object getObject (
        SQLParamController controller,
        StructuredMem mem) throws SQLException
    {
        return this.getTime (controller, mem);
    }
    /**
     *
     * @return java.sql.Date
     */
    public Time getTime (
        SQLParamController controller,
        StructuredMem mem)
    throws SQLException
    {
        String raw;
        Time result = null;

        if (!this.isNull (controller, mem)) {
            raw = mem.getString(this.bufpos, this.physicalLength - 1);
            result = Time.valueOf (raw);
        }
        return result;
    }
    /**
     *
     * @return java.sql.Date
     */
    public Timestamp getTimestamp (
        SQLParamController controller,
        StructuredMem mem)
    throws SQLException
    {
        String raw;
        Time timeValue = this.getTime (controller, mem);
        Timestamp result;

        if (timeValue == null) {
            return null;
        }
        result = new Timestamp (timeValue.getTime ());
        return result;
    }
    /**
     *
     * @return boolean
     */
    public boolean isCaseSensitive () {
        return false;
    }
    /**
     *
     * @param obj java.lang.Object
     */
    public Object transSpecificForInput (Object obj)
    throws SQLException
    {
        Object result = null;

        if (obj instanceof Time) {
            result = this.transTimeForInput ((Time) obj);
        }
        return result;
    }
    /**
     *
     * @param val java.lang.String
     */
    public Object transStringForInput (String val)
    throws SQLException
    {
        if (val == null) {
            return null;
        }
        try {
            return this.transTimeForInput (Time.valueOf (val));
        }
        catch (IllegalArgumentException exc) {
            // ignore, try timestamp
        }
        try {
            Timestamp ts = Timestamp.valueOf (val);
            return this.transTimeForInput (new Time (ts.getTime ()));
        }
        catch (IllegalArgumentException exc) {
            // possibly: try other parsing strategies
        }
        throw this.newParseException (val, "Time");
    }
    /**
     *
     * @param newValue java.sql.Time
     */
    public Object transTimeForInput (Time arg)
    throws java.sql.SQLException {
        if (arg == null) {
            return null;
        }
        else {
            return arg.toString ();
        }
    }
}