/*


    ========== licence begin LGPL
    Copyright (C) 2001 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

package com.sap.dbtech.powertoys;

import com.sap.dbtech.util.StructuredMem;
/**
 * Exception thrown when Loader command fails
 * @deprecated replaced by com.sap.dbtech.powertoys.LoaderException
 *
 */
public class RepmanException extends Exception
{
    private int errorCode;
    private String errorID;
    /**
     * creates a new RepmanException.
     */
    RepmanException (int eCode, String eID, String msg)
    {
        super (msg);
        this.errorCode = eCode;
        this.errorID = eID;
    }
    /**
     * returns the error code as set by dbm server.
     */
    public int getErrorCode ()
    {
        return this.errorCode;
    }
    /**
     * returns the symbolic equvalent of the error code.
     */
    public String getErrorID ()
    {
        return this.errorID;
    }
    /**
     * returns printable String of exception
     */
    public String toString ()
    {
        return "<RepmanException " + this.errorCode + " "
            + this.errorID + " " + this.getMessage () + ">";
    }
    /**
     *
     */
    static RepmanException create (StructuredMem packet)
    {
        int errorCode;
        String errorID;
        String message;
        String rawString;
        int chunkStart = 0;
        int chunkEnd;

        rawString = packet.getString (
            Repman.indicatorLengthC, packet.size () - Repman.indicatorLengthC);
        chunkEnd = rawString.indexOf (',');
        errorCode = Integer.parseInt (rawString.substring (0, chunkEnd));
        chunkStart = chunkEnd + 1;
        chunkEnd = rawString.indexOf (':', chunkStart);
        errorID = rawString.substring (chunkStart, chunkEnd);
        message = rawString.substring (chunkEnd + 1).trim ();
        return new RepmanException (errorCode, errorID, message);
    }
}

